#include "Pin.h"
#include "Beam.h"
#include "Unit.h"



Pin::Pin(SDL_Renderer* renderer, Vector2D setPos, bool setPositionFixed) :
	pos(setPos), positionFixed(setPositionFixed) {

	if (texture == nullptr)
		texture = TextureLoader::loadTexture(renderer, "Pin.bmp");
}



void Pin::update(float dT) {
	if (positionFixed == false && massSumStored > 0.0f) {
		//Calculate the acceleration, and update the velocity and position.
		Vector2D acc = forceSumStored / massSumStored;
		vel += acc * dT;
		pos += vel * dT;
	}
}



void Pin::draw(SDL_Renderer* renderer) {
	if (renderer != nullptr && texture != nullptr) {
		//Draw the pin image at it's position.
		SDL_Rect rect = {
			(int)round(pos.x - 28 / 2.0f),
			(int)round(pos.y - 28 / 2.0f),
			28,
			28 };
		SDL_RenderCopy(renderer, texture, NULL, &rect);
	}
}



void Pin::calculateForces(std::vector<std::shared_ptr<Beam>>& listBeams, Unit& unitRedCreature) {
	//Calculate all the forces and mass, in any beams that are attached to this and add them up.
	//Also add the force of gravity from the unit if it's touching the beam.
	forceSumStored = Vector2D();
	massSumStored = 0.0f;

	for (auto beamSelected : listBeams)
		if (beamSelected != nullptr && beamSelected->checkIfconnectedToPin(*this)) {
			beamSelected->addForceAndMassDiv2AtPin(*this, forceSumStored, massSumStored);

			if (unitRedCreature.checkIfTouchingBeam(beamSelected))
				unitRedCreature.addForceAtPin(forceSumStored);
		}
}



Vector2D Pin::getPos() {
	return pos;
}